<?php

namespace Schaffen\Gef\Models;

use App\Models\Cadastro\Pessoa;
use App\Models\Ged\Anexo;
use Illuminate\Database\Eloquent\Model;
use App\Models\Financeiro\MovimentacaoFinanceira;
use App\Models\Ged\Contrato;
use App\Models\Project\Obra;
use Prettus\Repository\Contracts\Transformable;
use Prettus\Repository\Traits\TransformableTrait;

/**
 * Class ApontamentoVeiculoGasto.
 *
 * @package namespace Schaffen\Gef\Models;
 */
class ApontamentoVeiculoGasto extends Model implements Transformable
{
   use TransformableTrait;

   public $timestamps = false;
   protected $table = "frota.apontamento_veiculo_gasto";
   protected $primaryKey = "avg_codigo";
   public static $prefix = 'avg_';

   /**
    * The attributes that are mass assignable.
    *
    * @var array
    */
   protected $fillable = ["avg_descricao","avg_fk_vei_codigo","avg_fk_responsavel_pes_codigo", "avg_fk_fornecedor_pes_codigo",
   "avg_fk_tra_codigo","avg_fk_con_codigo","avg_fk_mvf_codigo","avg_cobrar_cliente", "avg_data", "avg_fk_obr_codigo", "avg_fk_fil_codigo"];


   public function responsavel(){
      return $this->belongsTo(Pessoa::class, 'avg_fk_responsavel_pes_codigo');
   }

   public function contrato(){
      return $this->belongsTo(Contrato::class, 'avg_fk_con_codigo');
   }

   public function mvf(){
      return $this->hasManyThrough(
         MovimentacaoFinanceira::class, ApontamentoVeiculoGastoMvf::class, "avgm_fk_avg_codigo", "mvf_codigo", "avg_codigo"
      );
   }

   public function fornecedor(){
      return $this->belongsTo(Pessoa::class, 'avg_fk_fornecedor_pes_codigo');
   }

   public function veiculo(){
      return $this->belongsTo(Veiculo::class, 'avg_fk_vei_codigo');
   }

   public function obra(){
      return $this->belongsTo(Obra::class, 'avg_fk_obr_codigo');
   }

   public function items(){
      return $this->hasMany(ApontamentoVeiculoGastoItem::class, 'avgi_fk_avg_codigo');
   }

   public function anexos() {
      return $this->hasManyThrough(
         Anexo::class, ApontamentoVeiculoGastoAnexo::class, "avga_fk_avg_codigo", "ane_codigo", "avg_codigo"
      );
   }

}
