<?php

namespace Schaffen\Gef\Transformers;

use Carbon\Carbon;
use League\Fractal\TransformerAbstract;
use Schaffen\Gef\Models\ApontamentoVeiculoUso;

/**
 * Class ApontamentoVeiculoUsoTransformer.
 *
 * @package namespace Schaffen\Gef\Transformers;
 */
class ApontamentoVeiculoUsoTransformer extends TransformerAbstract
{
   /**
    * Transform the ApontamentoVeiculoUso entity.
    *
    * @param \Schaffen\Gef\Models\ApontamentoVeiculoUso $model
    *
    * @return array
    */
   public function transform(ApontamentoVeiculoUso $model)
   {


      $motorista = $model->motorista;
      $veiculo = $model->veiculo;
      $agendamento = $model->agendamento;

      if (!$model->avu_data_hora_uso_inical instanceof Carbon) {
         $model->avu_data_hora_uso_inical = Carbon::createFromFormat('Y-m-d H:i:s', $model->avu_data_hora_uso_inical);
      }

      if (!$model->avu_data_hora_uso_final instanceof Carbon) {
         $model->avu_data_hora_uso_final = Carbon::createFromFormat('Y-m-d H:i:s', $model->avu_data_hora_uso_final);
      }

      if (!empty($agendamento)) {
         if (!$agendamento->agu_data_disponibilidade_inicial instanceof Carbon) {
            $agendamento->agu_data_disponibilidade_inicial = Carbon::createFromFormat('Y-m-d', $agendamento->agu_data_disponibilidade_inicial)->format('d/m/Y');
         }

         if (!$agendamento->agu_data_disponibilidade_final instanceof Carbon) {
            $agendamento->agu_data_disponibilidade_final = Carbon::createFromFormat('Y-m-d', $agendamento->agu_data_disponibilidade_final)->format('d/m/Y');
         }
      }

      return [
         'codigo' => (int)$model->avu_codigo,
         'data_hora_uso_inical' => $model->avu_data_hora_uso_inical->format('d/m/Y H:i:s'),
         'data_hora_uso_final' => $model->avu_data_hora_uso_final->format('d/m/Y H:i:s'),
         'observacao' => $model->avu_observacao,
         'km_inicial' => $model->avu_km_inicial,
         'km_final' => $model->avu_km_final,
         'motorista' => $motorista->pes_nome,
         'veiculo' => !isset($veiculo->vei_identificador) ? $veiculo->vei_placa : $veiculo->vei_identificador,
         'agendamento' => isset($agendamento->agu_codigo) ? $agendamento->agu_data_disponibilidade_inicial . ' até ' . $agendamento->agu_data_disponibilidade_final : null,
         'obra' => isset($model->obra) ? $model->obra->obr_descricao : null
      ];

   }
}
